@@ -1,6 +1,5 @@
-##' @S3method model.frame lvmfit
+##' @export
 model.frame.lvmfit <- function(formula, all=FALSE,...) {
-  dots <- list(...)
   mydata <- formula$data$model.frame
   if (!is.data.frame(mydata) & !is.matrix(mydata))
     return(mydata)
@@ -10,9 +9,8 @@ model.frame.lvmfit <- function(formula, all=FALSE,...) {
   return( mydata[,c(manifest(formula),xfix),drop=FALSE] )
 }
 
-##' @S3method model.frame multigroupfit
+##' @export
 model.frame.multigroupfit <- function(formula,...) {
-  dots <- list(...)
   mydata <- formula$model$data
   return(mydata)
 }
