@@ -150,7 +150,7 @@ test_that("Bootstrap", {
     testthat::expect_true(B2$bollenstine)
     testthat::expect_true(nrow(B1$coef)==2)
     testthat::expect_output(print(B1),"Standard errors:")
-    if (requireNamespace("foreach",quietly=TRUE)) foreach::registerDoSEQ()
+    # if (requireNamespace("future",quietly=TRUE)) future::plan("sequential")
     dm <- capture.output(B3 <- bootstrap(e,R=2,fun=function(x) coef(x)[2]^2+10))
     testthat::expect_true(all(mean(B3$coef)>10))
 
@@ -175,7 +175,7 @@ test_that("Survreg", {
     testthat::expect_true(length(pars(m))==length(coef(m))+1)
     testthat::expect_true(abs(attr(score(m,pars(m)),'logLik')-logLik(m))<1e-9)
     testthat::expect_true(mean(colSums(s)^2)<1e-6)
-    testthat::expect_equivalent(vcov(m),attr(s,'bread'))
+    testthat::expect_equivalent(vcov(m), attr(s,'bread')/nrow(d))
 })
 
 
@@ -509,3 +509,16 @@ test_that("Tobit",{
     e <- estimate(m,data=d,estimator="normal",weights="w")
     testthat::expect_true(mean((coef(e)[1:2]-coef(s))^2)<1e-9)
 })
+
+test_that("GEE", {
+  require("geepack")
+  d <- lvm(y ~ x, ~ id) |>
+    distribution(~id, uniform.lvm(value=seq(1:20))) |>
+    sim(100, seed=1)
+  d0 <- d[order(d$id), ]
+  g <- geeglm(y ~ x, data=d0, id=d0$id)
+  V <- summary(g)$cov.scaled
+  g0 <- glm(y ~ x, data=d)
+  V0 <- vcov(estimate(g0, id = d$id))
+  testthat::expect_true(sum((V - V0)^2) < 1e-12)
+})
